import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.io.*;
import javax.swing.text.*;
import java.lang.Runtime;

public class LauncherPanel extends JPanel implements ActionListener {

	private JTextField cmdLineField;
	private JLabel enterLineLabel;
	private JComboBox modComboBox;
	private String[] modList;
	private String cod4Path;
	private File cod4ModsFolder;
	private JButton updateLibrary;
	private JButton run;
	private Mod[] mods;

	public LauncherPanel() {

		cod4Path = (new RegQuery()).start();

		cod4ModsFolder = new File(cod4Path + "\\mods\\");

		String[] modList = cod4ModsFolder.list();

		int numOfMods = countDirs(modList);

		mods = new Mod[numOfMods];

		for(int i = 0; i < mods.length; i++) {
			for(int j = 0; j < modList.length; j++) {
				if(modList[j] != null && isDir(modList[j])) {
					mods[i] = new Mod(modList[j]);
					modList[j] = null;
					break;
				}
			}
		}

		makeLibrary();

		modComboBox = new JComboBox();
		enterLineLabel = new JLabel("      Enter the command line:      ");
		cmdLineField = new JTextField(25);
		updateLibrary = new JButton("Update Library");
		run = new JButton("Run the mod");

		for(int i = 0; i < mods.length; i++) {
			modComboBox.addItem(mods[i].toString());
		}

		modComboBox.addActionListener(this);
		updateLibrary.addActionListener(this);
		run.addActionListener(this);

		cmdLineField.setText(mods[0].getCommandLine());

		add(modComboBox);
		add(enterLineLabel);
		add(cmdLineField);
		add(updateLibrary);
		add(run);

	}

  	public void paintComponent(Graphics g){
		super.paintComponent(g);

 	}

 	public void actionPerformed(ActionEvent e) {
		if(e.getSource() == modComboBox) {
			updateTextField();
		} else if(e.getSource() == updateLibrary) {
			updateObject();
			writeLibrary();
		} else if(e.getSource() == run) {
			createBatchFile();
			runBatchFile();
		}
	}

	private int countDirs(String[] list) {
		int counter = 0;
		for(int i = 0; i < list.length; i++) {
			File mod = new File(cod4ModsFolder + "\\" + list[i]);
			if(mod.isDirectory()) {
				counter++;
			}
		}
		return counter;
	}

	private boolean isDir(String fileName) {
		File mod = new File(cod4ModsFolder + "\\" + fileName);
		return mod.isDirectory();
	}

	private void createBatchFile() {
		String currentMod = (String)(modComboBox.getSelectedItem());
		try{
			PrintWriter writeBatch = new PrintWriter(new FileWriter("RunMod.bat"));
			writeBatch.println("@ECHO OFF");
			writeBatch.println("cd /d " + cod4Path);
			writeBatch.println("iw3mp.exe " + cmdLineField.getText());
			writeBatch.print("EXIT");
			writeBatch.close();
			run.setText("Success!");
		} catch (IOException ex) {
			run.setText("Error :(");
		}
	}

	private void runBatchFile() {
		try {
			ProcessBuilder runBatch = new ProcessBuilder("cmd.exe", "/c start " + "RunMod.bat");
			Process p = runBatch.start();
		} catch (Exception e) {
			run.setText("Error");
		}
	}

	private void makeLibrary() {
		File library = new File("ModParamList.txt");
		if(!library.exists()) {
			writeLibrary();
		} else {
			readFromLibrary();
		}
	}

	private void readFromLibrary() {
		try {
			BufferedReader readLibrary = new BufferedReader(new FileReader("ModParamList.txt"));
			String line;
			while ((line = readLibrary.readLine()) != null) {
				for(int i = 0; i < mods.length; i++) {
					if((line.substring(0, line.indexOf(":"))).equals(mods[i].toString())) {
						mods[i].setCommandLine(line.substring(line.indexOf("+"), line.length()));
						break;
					}
				}
			}

			readLibrary.close();
		} catch (Exception e) {

		}
	}

	private void writeLibrary() {
		try {
			File libraryFile = new File("ModParamList.txt");
			if(libraryFile.exists()) {
				libraryFile.delete();
			}
			PrintWriter writeLibrary = new PrintWriter(new FileWriter("ModParamList.txt"));
			for(int i = 0; i < mods.length; i++) {
				mods[i].printModName(writeLibrary);
				mods[i].printCommandLine(writeLibrary);
			}

			writeLibrary.close();
		} catch (Exception e) {
			System.out.println(e);
		}
	}

	private void updateTextField() {
		try {
			BufferedReader readLibrary = new BufferedReader(new FileReader("ModParamList.txt"));
			String line;
			String boxItem = (String)(modComboBox.getSelectedItem());
			while ((line = readLibrary.readLine()) != null) {
				for(int j = 0; j < mods.length; j++) {
					if((mods[j].toString()).equals(boxItem)) {
						cmdLineField.setText(mods[j].getCommandLine());
					}
				}
				return;
			}
			readLibrary.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	private void updateObject() {
		String boxItem = (String)(modComboBox.getSelectedItem());
		for(int j = 0; j < mods.length; j++) {
			if((mods[j].toString()).equals(boxItem)) {
				mods[j].setCommandLine(cmdLineField.getText());
			}
		}
	}
}
